@@ -7,9 +7,9 @@ import theano
 from tests import unittest_tools as utt
 from theano import gradient
 from theano.configdefaults import config
-from theano.gof.graph import Apply
-from theano.gof.null_type import NullType
-from theano.gof.op import Op
+from theano.graph.basic import Apply
+from theano.graph.null_type import NullType
+from theano.graph.op import Op
 from theano.sandbox.rng_mrg import MRG_RandomStream
 
 
@@ -22,7 +22,9 @@ def grad_sources_inputs(sources, inputs):
     the new interface so the tests don't need to be rewritten.
     """
     if inputs is None:
-        inputs = list(theano.gof.graph.inputs([source[0] for source in sources]))
+        inputs = list(
+            theano.graph.basic.graph_inputs([source[0] for source in sources])
+        )
     return dict(
         zip(
             inputs,
@@ -51,6 +53,9 @@ class TestGradSourcesInputs:
                 (x,) = inp
                 (gz,) = grads
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a = retNone().make_node()
         with pytest.raises(TypeError):
             grad_sources_inputs([(a.out, one)], None)
@@ -68,6 +73,9 @@ class TestGradSourcesInputs:
             def grad(self, inputs, grads):
                 return [inputs[0].zeros_like()]
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         i = theano.tensor.vector()
         j = theano.tensor.vector()
         a1 = retOne().make_node(i)
@@ -91,6 +99,9 @@ class TestGradSourcesInputs:
             def grad(self, inp, grads):
                 return (gval,)
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a1 = TestOp().make_node()
         g = grad_sources_inputs([(a1.outputs[0], one)], None)
         assert g[a1.inputs[0]] is gval
@@ -112,6 +123,9 @@ class TestGradSourcesInputs:
                 gz1, gz2 = grads
                 return (gval,)
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a1 = TestOp().make_node()
         g = grad_sources_inputs([(a1.outputs[0], one)], None)
         assert g[a1.inputs[0]] is gval
@@ -134,6 +148,9 @@ class TestGradSourcesInputs:
                 (gz,) = grads
                 return (gval0, gval1)
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a1 = TestOp().make_node()
         g = grad_sources_inputs([(a1.outputs[0], one)], None)
         assert g[a1.inputs[0]] is gval0
@@ -155,6 +172,9 @@ class TestGradSourcesInputs:
             def grad(self, inp, grads):
                 return gval0, gval1
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a1 = TestOp().make_node()
         g = grad_sources_inputs([(a1.outputs[0], one)], None)
         assert g[a1.inputs[0]] is gval0
@@ -190,6 +210,9 @@ class TestGrad:
             def grad(self, inputs, output_grads):
                 return [theano.gradient.grad_not_implemented(self, 0, inputs[0])]
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a = theano.tensor.scalar()
         b = DummyOp()(a)
 
@@ -208,6 +231,9 @@ class TestGrad:
             def grad(self, inputs, output_grads):
                 return [theano.gradient.grad_undefined(self, 0, inputs[0])]
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         a = theano.tensor.scalar()
         b = DummyOp()(a)
 
@@ -370,7 +396,7 @@ class TestGrad:
             __props__ = ()
 
             def make_node(self, x):
-                return theano.Apply(
+                return Apply(
                     self, inputs=[x], outputs=[x.type(), theano.tensor.scalar()]
                 )
 
@@ -380,19 +406,23 @@ class TestGrad:
             def grad(self, inputs, output_grads):
                 return [inputs[0].zeros_like()]
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         # Op2 has two inputs, f and g
         # Its gradient with respect to g is not defined
         class Op2(Op):
             __props__ = ()
 
             def make_node(self, f, g):
-                return theano.Apply(
-                    self, inputs=[f, g], outputs=[theano.tensor.scalar()]
-                )
+                return Apply(self, inputs=[f, g], outputs=[theano.tensor.scalar()])
 
             def grad(self, inputs, output_grads):
                 return [inputs[0].zeros_like(), NullType()()]
 
+            def perform(self, *args, **kwargs):
+                raise NotImplementedError()
+
         x = theano.tensor.vector()
         f, g = Op1()(x)
         cost = Op2()(f, g)
