@@ -14,7 +14,8 @@ except ImportError:
 
 import theano.tensor
 from theano import tensor
-from theano.gof import Apply, Op
+from theano.graph.basic import Apply
+from theano.graph.op import Op
 from theano.tensor import as_tensor_variable
 
 
